function [ ...
    objVelocityF,...  %Object Velocity (ovx,ovy)
   objCentroidF,...   %Object Centroid (ox,oy)
   objCentrodC,...  %Centroid(ox,oy)-origin(x,y)
   objEccF,...            % Object eccentricity
   objAreaF, ...        %Area of object
   objBoxF ...           % rectangular region of the object
   ] = detectAsteroide_run( ...
    Data,...                 %sum&shift image
    origin,...               % [row min, col min]
     %imageSizeFlag, ...   % 0: Original Image 1: Shifted image size
    theV, ...               %frame Velocity
    facStd,...             %standar deviation factor
    radius,...              % minimum search asteroid radius 
    eccentricity ...    % maximum asteroid eccentricity
    )
%Detection of candidate asteroids from an image where the 
% add&shift operator was applied to the data cube at a certain speed.
% INPUT 
%   Data: sum&shift image
%   origin: [row min, col min]
%   imageSizeFlag: [0|1];
%           0: Original Image
%           1: Shifted image size
%   theV: frame Velocity
%   facStd: standar deviation factor
%   radius: minimum search asteroid radius  
%   eccentricity: maximum asteroid eccentricity
%
%OUTPUT
%   objVelocityF: Object Velocity (ovx,ovy)
%   objCentroidF:   Object Centroid (ox,oy)
%   objCentrodC: Corrected postion of Centroid(ox,oy)-origin(x,y)
%   objEccF: Object eccentricity
%   objAreaF:  Area of object
%   objBoxF: rectangular region of the object
% BHV Nov 2021

%if imageSizeFlag
    A=normalizeData(Data,'log');
%else
%    A=normalizeData(Data,'log');
%end


a=mean(A(:));
b=std(A(:));
u1=a+facStd*b; % low valud above "facStd" of std
%u2=a+3*b; %Upper values above 3 times std 
B1=A>u1;
%B2=A<u2;
%B=B1.*B2;
B=B1;
B=logical(B);

morfR=strel('disk',radius,0);
C=imopen(B,morfR);

minBlobArea=round(pi*radius^2);
maxBlobArea=round(3*pi*radius^2);
maxBlobCount=5000;
theBlob=vision.BlobAnalysis('MinimumBlobArea',minBlobArea,...
    'MaximumBlobArea',maxBlobArea,'MaximumCount',maxBlobCount, ...
    'EccentricityOutputPort', 1);

%[objArea,objCentroid,objBox,objMay,objMin,objOri,objEcc]=step(theBlob,C);
[objArea,objCentroid,objBox,objEcc]=step(theBlob,C);
numObj=numel(objArea);
finalObj=0;
for ii=1:numObj
    if (objEcc(ii) <  eccentricity && objEcc(ii) >= 0 )
        finalObj=finalObj+1;
        objAreaF(finalObj)=objArea(ii); 
        objCentroidF(finalObj,:)=objCentroid(ii,:);
        objBoxF(finalObj,:)=objBox(ii,:);
        objEccF(finalObj)=objEcc(ii);
        objCentrodC(finalObj,:)=origin;
        objVelocityF(finalObj,:)=theV;
    end
end



end

