function [ImageSize, RefPixel, CDMatrix ] = fitsRead_TRvalue( filename, debug )
%fitsRead_TRvalue read the Reference pixel_point and Rotations_scaling
% matrix, from WCS fits file in homogeneous coordinate system
% Input: filename
% Output: RefPixel(CRPIX1,CRPIX2)
%         RotScale(CD1_1,CD1_2;CD2_1,CD2_2)

if exist(filename,'file') ~= 2
    error('\n Error: List file %s does not exist ... \n aborting...',...
        filename);
  
end

import matlab.io.*
fptr = fits.openFile(filename);
n = fits.getNumHDUs(fptr);

ImageSize=zeros(2,1);
RefPixel=zeros(2,1);
CDMatrix=zeros(2,2);
naxis=0;

%theError=0;

for j = 1:n
    fits.movAbsHDU(fptr,j);
    
    [elval,~]=fits.readKey(fptr,'WCSAXES');
    naxis=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'IMAGEW');
    ImageSize(1)=str2double(elval);
    %[elval,~]=fits.readKey(fptr,'NAXIS1');
    %ImageSize(1)=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'IMAGEH');
    ImageSize(2)=str2double(elval);
    %[elval,~]=fits.readKey(fptr,'NAXIS2');
    %ImageSize(2)=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'CRPIX1');
    RefPixel(1)=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'CRPIX2');
    RefPixel(2)=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'CD1_1');
    CDMatrix(1,1)=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'CD1_2');
    CDMatrix(1,2)=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'CD2_1');
    CDMatrix(2,1)=str2double(elval);
    
    [elval,~]=fits.readKey(fptr,'CD2_2');
    CDMatrix(2,2)=str2double(elval);
    
end
fits.closeFile(fptr);

if ( naxis ~= 2 )
    
    error('Error: \n The file %s is not a bidmentional data Naxis=%d',...
        filename,naxis);

end


if debug
     fprintf('debug: Image file name: %s\n',filename);
     fprintf('debug: Image Size\ndebug: [%d X %d ]:\n', ...
         ImageSize(1),ImageSize(2));
     fprintf('debug: Reference Pixel\ndebug: [%f,%f,%f]:\n', ...
         RefPixel(1),RefPixel(2),RefPixel(3) );
     fprintf('debug: Rotation and Scaling Matrix\n');
     for j=1:3
          fprintf('debug: [%d] %+f, %+f, %+f\n',j,...
              CDMatrix(j,1),CDMatrix(j,2),CDMatrix(j,3) );
     end
     fprintf('\n');
end
    



end
