function [ theMask,objCentroid, objArea,objBox,numObj,finalFactor,skMedian] = maskMedian_Type( ...
    Data,...
    theRegions,...,
    theFactor, ...
    radius, ...
    minStars, ...
    maxStars, ...
    TF,...
    debug)
% Compute the mask of a image (Data) with N times greate that the background according the selected regions
% Usage:  [ theMask ] = maskMedian( Data,theRegions,timeBackground, debug)
%Input:
% Data:The Median image
%Regions: Sky regions (Xcenter, Y Center, Width, Hight)
%timeBackground: Pixels over N  times the sky background 
% radius: Radius of the dilation mask
%debug:  0: no debug; 1: some basic info; 2: more vervosity
%
%Output:
% theMask: the logical mask
%
%
% BH Jun 2021

if TF(1)
    [skMedian,~,~]=skyAdjustOnlyStats(Data,theRegions);
    %Data(Data < skMedian)=skMedian;
else
    skMedian=std(Data(:));
end

Data(Data < skMedian)=skMedian;


theImgL=log(Data);
fact=1/(max(theImgL(:))-min(theImgL(:)));
themin=min(theImgL(:));
theImgNor=(theImgL - themin).*fact;

if(theFactor <= 0)
    % 2.5 times the sky background
    newThresh= (log(2.5*skMedian)-themin)*fact;
else
    newThresh=(log(theFactor*skMedian)-themin)*fact;
end
 newThreshB= (log(skMedian)-themin)*fact;
%first analize the image 
 maxIter=0;
 finalThresh=newThresh;
 morf_r2=strel('disk',1,0);
 minBlobArea=round(5);
 maxBlobArea=8000;   
 maxBlobCount=round(maxStars+(0.1*maxStars));
 
 threshDev=0.3;
  maxThresh=newThresh+abs(threshDev);
  minThresh=newThresh-abs(threshDev);
  if minThresh < newThreshB 
      minThresh=newThreshB;
  end
 
 while (maxIter < 250)
     maxIter=maxIter+1;
     theImg_A=theImgNor>finalThresh;
     theImg_B=imopen( theImg_A,morf_r2);
     theBlob=vision.BlobAnalysis('MinimumBlobArea',minBlobArea,...
          'MaximumBlobArea',maxBlobArea,'MaximumCount',maxBlobCount);   
     [objArea,objCentroid,objBox]=step(theBlob,theImg_B);
      numObj=numel(objArea);
      
      if (numObj >  maxStars)
                minThresh=finalThresh;
            delta=(maxThresh-finalThresh)/2;
            finalThresh=finalThresh+delta;
        elseif (numObj < minStars)
            maxThresh=finalThresh;
            delta=(finalThresh-minThresh)/2;
            finalThresh=finalThresh-delta;
        else
            break;
        end
 end 

 % Dilate te Image with a circular morfological mask with r=1pix
 % The intention is capture the entire  PSF 
 morf_r3=strel('disk',radius,0);
 theMask=imdilate(theImg_B, morf_r3);
 theBlob=vision.BlobAnalysis('MinimumBlobArea',minBlobArea,...
          'MaximumBlobArea',maxBlobArea,'MaximumCount',maxBlobCount);   
[objArea,objCentroid,objBox]=step(theBlob,theMask);

 numObj=numel(objArea);
 [objArea, theIdx]=sort(objArea,'descend');
 objCentroid=objCentroid(theIdx,:);
 objBox=objBox(theIdx,:);
 
 finalFactor=exp( finalThresh/fact + themin - log(skMedian));
    
   if debug
     if debug == 2
       figure(1)
       subplot(1,3,1);
        imshow(theImgNor); 
        title('Median Image');
        c = colorbar('southoutside');
        c.Label.String = 'log';
        
        subplot(1,3,2);
        imshow(theImg_A); 
        t=sprintf('Median Image: Threshold: %4.2f',newThresh);
        title(t);
        c = colorbar('southoutside');
        c.Label.String = 'binary';
        
        subplot(1,3,3);
        imshow(theMask); 
        t=sprintf('Morfoligical dilation disk r=%d',radius);
        title(t);
        c = colorbar('southoutside');
        c.Label.String = 'binary';
        pause(1);
     end
      
         numObj=numel(objArea);
        delta=2;
        bboxOut_2(:,1)=objBox(:,1)-delta;
        bboxOut_2(:,2)=objBox(:,2)-delta;
        bboxOut_2(:,3)=objBox(:,3)+2*delta;
        bboxOut_2(:,4)=objBox(:,4)+2*delta;
        imgShape= insertShape(theImgNor,'rectangle',bboxOut_2,'Linewidth',2,'Color',[255 0 0]);
        figure(2);
        pause(1);
        imshow(imgShape);
        t=sprintf('Number of starts to be masked:  %d',numObj); 
        title(t);
 end
        
end

