function [R,t] = rigidTransform2D(A, ReferenceB)
% Finds the optimal Rigid/Euclidean transform in 2D space A-->B
% B=RA+t
% It expects as input a 2xN matrix of 2D points.
% It returns R, t
% 

% Due points A,B is a row vector I need to conver in Column Vector

    At=A.';
    ReferenceBt=ReferenceB.';
  

    [num_rows, num_cols] = size(At);
    if num_rows ~= 2
        error(" Coordinate Point vector At is not 2xN, it is %dx%d", num_rows, num_cols);
    end

    [num_rows, num_cols] = size(ReferenceBt);
    if num_rows ~= 2
        error("Coordinate Refererance Point vector Bt is not 2xN, it is %dx%d", num_rows, num_cols)
    end

    % find mean column wise
    centroid_A = mean(At, 2);
    centroid_B = mean(ReferenceBt, 2);

    % subtract mean
    Am = At - repmat(centroid_A, 1, num_cols);
    Bm = ReferenceBt - repmat(centroid_B, 1, num_cols);

    % calculate covariance matrix
    H = Am * Bm';

    % find rotation
    [U,S,V] = svd(H);
    R = V*U';

    if det(R) < 0
        fprintf("Warning: det(R) < 0, reflection detected!, correcting  ...\n");
        V(:,2) =    V(:,2) .* (-1);
        R = V*U';
    end

    t = -R*centroid_A + centroid_B;
end
