function [ theSS, minC, maxC, theV ] = vpixSumShift( Data, velX,velY)
%Sum & Shift data cube according a constant velocity defined by vector
%velocity (Vini,Vend,Vdelta)
%   Usage:
%
%Input:
%Data: The Data Cube
%velX: the velocity vector over X axis (VXini,VXend,VXdelta)
%velY: the velocity vector over Y axis (VYini,VYend,VYdelta)
%
% Output:
%theSS: Data cube summed and shifted 
%minC: min coordenate (Xmin, Ymin)
%maxC: max coordenate (Xmax, Ymax)
%theV: Velicty (Vx,Vy) data cube
%
%Jun 2021
%BH


nx=abs(floor( (velX(2)-velX(1)) / velX(3) ))+1;
a=rem( velX(2)-velX(1) ,  velX(3));
if a ~= 0
    nx=nx+1;
end
Vx=linspace(velX(1),velX(1)+(nx-1)*velX(3),nx);

ny=abs(floor( (velY(2)-velY(1)) /velY(3) )) +1;
a=rem( velY(2)-velY(1) ,  velY(3));
if a ~= 0
    ny=ny+1;
end
Vy=linspace(velY(1),velY(1)+(ny-1)*velY(3),ny);


[rtot,ctot,~]=size(Data);

sflag=0;


nmovX=length(Vx);
nmovY=length(Vy);
theSS=zeros(rtot,ctot,nmovX*nmovY);

minC=zeros(2,nmovX*nmovY);
maxC=zeros(2,nmovX*nmovY);
theV=zeros(2,nmovX*nmovY); 

c=0;
for vx=1:nmovX
    for vy=1:nmovY
        c=c+1;
        theV(1,c)=Vx(vx);
        theV(2,c)=Vy(vy);
        [theSS(:,:,c),minC(:,c),maxC(:,c)]=...
            sumShift(Data,theV(:,c),sflag);
    end
end

end

